<p align="center">
  <a href="https://github.com/linuxdeepin/youqu">
    <img src="./assets/logo.png" width="100" alt="YouQu3">
  </a>
</p>
<h1 align="center">YouQu3</h1>
<p align="center">
    <em>Next-Gen Linux Autotest Framework.</em>
</p>


![Python](https://img.shields.io/badge/Python-007CFF?style=for-the-badge&logo=Python&logoColor=white)
![Linux](https://img.shields.io/badge/Linux-007CFF?style=for-the-badge&logo=linux&logoColor=white)

![PyPI](https://img.shields.io/pypi/v/youqu3?style=flat&logo=github&link=https%3A%2F%2Fpypi.org%2Fproject%2Fyouqu3%2F&color=%23F79431)
![Downloads](https://static.pepy.tech/badge/youqu3)

--------------

文档：https://youqu.uniontech.com/

--------------

**YouQu3** 是下一代 Linux 自动化测试框架，功能强大，使用简单，专注于用例开发管理、驱动执行。

## 安装

基础环境：

```bash
pip3 install youqu3
```

## 创建用例工程

创建一个目录

```bash
mkdir my_autotest
```

使用脚手架功能创建用例工程

```bash
cd my_autotest/
youqu3 init
```

## 驱动执行

```bash
youqu3 run
```

更多详细功能请查看在线文档。

## 开源许可证

YouQu3 在 [GPL-2.0](https://github.com/linuxdeepin/youqu/blob/main/LICENSE) 下发布
